==> jc-1.4.0.tar.gz: javax/transaction/HeuristicMixedException.h <==
// public class javax.transaction.HeuristicMixedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3d082000f9cf0304 javax_transaction_HeuristicMixedException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_transaction_HeuristicMixedException_H_
#define _JC_javax_transaction_HeuristicMixedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_HeuristicMixedException$sub_refs	_jc_javax_transaction_HeuristicMixedException$sub_refs;
typedef struct _jc_javax_transaction_HeuristicMixedException$sub_nonrefs	_jc_javax_transaction_HeuristicMixedException$sub_nonrefs;
typedef struct _jc_javax_transaction_HeuristicMixedException$refs	_jc_javax_transaction_HeuristicMixedException$refs;
typedef struct _jc_javax_transaction_HeuristicMixedException$nonrefs	_jc_javax_transaction_HeuristicMixedException$nonrefs;
typedef struct _jc_javax_transaction_HeuristicMixedException$object	_jc_javax_transaction_HeuristicMixedException$object;

typedef const struct _jc_javax_transaction_HeuristicMixedException$vmethods	_jc_javax_transaction_HeuristicMixedException$vmethods;
typedef const struct _jc_javax_transaction_HeuristicMixedException$vtable	_jc_javax_transaction_HeuristicMixedException$vtable;
typedef const struct _jc_javax_transaction_HeuristicMixedException$vtype	_jc_javax_transaction_HeuristicMixedException$vtype;

// Constructors
extern void _jc_javax_transaction_HeuristicMixedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_HeuristicMixedException$object *);
extern void _jc_javax_transaction_HeuristicMixedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_HeuristicMixedException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_transaction_HeuristicMixedException$vmethods {
};

// Vtable
struct _jc_javax_transaction_HeuristicMixedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_transaction_HeuristicMixedException$vmethods	javax_transaction_HeuristicMixedException;
};

// Vtype
struct _jc_javax_transaction_HeuristicMixedException$vtype {
	_jc_type			type;
	_jc_javax_transaction_HeuristicMixedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_HeuristicMixedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_HeuristicMixedException$refs {
    _jc_javax_transaction_HeuristicMixedException$sub_refs	javax_transaction_HeuristicMixedException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_HeuristicMixedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_HeuristicMixedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_transaction_HeuristicMixedException$sub_nonrefs	javax_transaction_HeuristicMixedException;
};

// Object instance structure
struct _jc_javax_transaction_HeuristicMixedException$object {
	_jc_javax_transaction_HeuristicMixedException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_HeuristicMixedException$vtype	*vtype;
	_jc_javax_transaction_HeuristicMixedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_HeuristicMixedException$vtype _jc_javax_transaction_HeuristicMixedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_HeuristicMixedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_HeuristicMixedException$class_object;

#endif	/* _JC_javax_transaction_HeuristicMixedException_H_ */

==> jc-1.4.6.tar.gz: javax/transaction/HeuristicMixedException.h <==
// public class javax.transaction.HeuristicMixedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3d082000f9cf0304 javax_transaction_HeuristicMixedException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_transaction_HeuristicMixedException_H_
#define _JC_javax_transaction_HeuristicMixedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_HeuristicMixedException$sub_refs	_jc_javax_transaction_HeuristicMixedException$sub_refs;
typedef struct _jc_javax_transaction_HeuristicMixedException$sub_nonrefs	_jc_javax_transaction_HeuristicMixedException$sub_nonrefs;
typedef struct _jc_javax_transaction_HeuristicMixedException$refs	_jc_javax_transaction_HeuristicMixedException$refs;
typedef struct _jc_javax_transaction_HeuristicMixedException$nonrefs	_jc_javax_transaction_HeuristicMixedException$nonrefs;
typedef struct _jc_javax_transaction_HeuristicMixedException$object	_jc_javax_transaction_HeuristicMixedException$object;

typedef const struct _jc_javax_transaction_HeuristicMixedException$vmethods	_jc_javax_transaction_HeuristicMixedException$vmethods;
typedef const struct _jc_javax_transaction_HeuristicMixedException$vtable	_jc_javax_transaction_HeuristicMixedException$vtable;
typedef const struct _jc_javax_transaction_HeuristicMixedException$vtype	_jc_javax_transaction_HeuristicMixedException$vtype;

// Constructors
extern void _jc_javax_transaction_HeuristicMixedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_HeuristicMixedException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_transaction_HeuristicMixedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_HeuristicMixedException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_transaction_HeuristicMixedException$vmethods {
};

// Vtable
struct _jc_javax_transaction_HeuristicMixedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_transaction_HeuristicMixedException$vmethods	javax_transaction_HeuristicMixedException;
};

// Vtype
struct _jc_javax_transaction_HeuristicMixedException$vtype {
	_jc_type			type;
	_jc_javax_transaction_HeuristicMixedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_HeuristicMixedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_HeuristicMixedException$refs {
    _jc_javax_transaction_HeuristicMixedException$sub_refs	javax_transaction_HeuristicMixedException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_HeuristicMixedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_HeuristicMixedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_transaction_HeuristicMixedException$sub_nonrefs	javax_transaction_HeuristicMixedException;
};

// Object instance structure
struct _jc_javax_transaction_HeuristicMixedException$object {
	_jc_javax_transaction_HeuristicMixedException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_HeuristicMixedException$vtype	*vtype;
	_jc_javax_transaction_HeuristicMixedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_HeuristicMixedException$vtype _jc_javax_transaction_HeuristicMixedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_HeuristicMixedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_HeuristicMixedException$class_object;

#endif	/* _JC_javax_transaction_HeuristicMixedException_H_ */
